function res = f_PCA_identifiability(orig_matrix,Test_index,Retest_index,configs)


%% This function is based on the publication
%  The quest for identifiability in human functional connectomes (2018) Amico E, Goñi J. Scientific Reports 8.1: 8254
%  https://doi.org/10.1038/s41598-018-25089-1

%% Compute Identifiability matrix, original FCs
orig_matrix_test = orig_matrix(:,Test_index);
orig_matrix_retest = orig_matrix(:,Retest_index);   
Ident_mat_orig = corr(orig_matrix_retest,orig_matrix_test); 

%% Initialization of arrays to store fingerprinting scores for 
%% reconstructed connectivty data (indexed by number of components).

Idiff_recon   = zeros(1,configs.max_numPCs); %Initialization for differential identifiability 
ID_rate_recon = zeros(1,configs.max_numPCs); %Initialization for identification rate 
M_rate_recon  = zeros(1,configs.max_numPCs); %Initialization for matching rate

%% Differential Identifiability (Idiff) evaluation of PCA decomposition into FC-modes (see also Fig.2 of Amico & Goñi, SciRep 2018)
PCA_comps_range = 2:configs.max_numPCs; % Note that at least 2 PCA components are needed for Idiff evaluation
[FC_modes, projected_FC_modes] = pca(orig_matrix,'NumComponents',configs.max_numPCs);     
for i= PCA_comps_range
    recon_matrix = projected_FC_modes(:,1:i) * FC_modes(:,1:i)'; % PCA reconstructed demeaned data    
    recon_matrix = bsxfun(@plus, recon_matrix,mean(orig_matrix)); % plug the mean back
    recon_matrix_test = recon_matrix(:,Test_index);
    recon_matrix_retest = recon_matrix(:,Retest_index);
    %% Compute Identifiability matrix, reconstructed FCs
    Ident_mat_recon = corr(recon_matrix_retest,recon_matrix_test);
    %% Idiff computation, reconstructed FCs
    %% %% Compute three fingerprinting metrics : Idiff, ID_rate and M_rate
    [Idiff,ID_rate,M_rate] = f_compute_id_metrics(Ident_mat_recon);
    
    Idiff_recon(i)   = Idiff;
    ID_rate_recon(i) = ID_rate;
    M_rate_recon(i)  = M_rate;
end

%% Identifiability matrix at optimal reconstruction (see also Fig 3C1 in Amico & Goñi, SciRep 2018)
% Idiff_opt = max(Idiff_recon);
% m_star = PCA_comps_range(Idiff_recon(2:end)==Idiff_opt); % obtain the optimal number of PCA components for reconstruction. First point is intentionally skipped since range of components starts on 2.
% recon_matrix_opt = projected_FC_modes(:,1:m_star) * FC_modes(:,1:m_star)'; % PCA reconstructed demeaned data    
% recon_matrix_opt = bsxfun(@plus, recon_matrix_opt,mean(orig_matrix)); % plug the mean back
% recon_matrix_opt_test = recon_matrix_opt(:,Test_index);
% recon_matrix_opt_retest = recon_matrix_opt(:,Retest_index);
% %% Compute Recon Identifiability matrix at optimal point
% Ident_mat_recon_opt = corr(recon_matrix_opt_retest,recon_matrix_opt_test);

%% Wrap-up results in results structure
res.Ident_mat_orig 		= Ident_mat_orig;
res.Idiff_recon 		= Idiff_recon;
res.ID_rate_recon 		= ID_rate_recon;
res.M_rate_recon 		= M_rate_recon;
% res.Idiff_opt 			= Idiff_opt;
% res.recon_matrix_opt 	= recon_matrix_opt;
% res.Ident_mat_recon_opt = Ident_mat_recon_opt;
% res.PCA_comps_range 	= PCA_comps_range;
% res.m_star 				= m_star;
