function hFig = f_plot_results(res_baseline,res_absolute,res_normalized)

%% This function plots the Idiff, ID_rate and M_rate profiles based on
%% the results of the PCA decomposition-reconstruction of the baseline,
%% absolute and normalized FCs
%
%  INPUTS :
%           - res_baseline, res_absolute, res_normalized : results
%           structure returned by f_PCA_identifiability, resp. for
%           baseline, absolute and normalized FCs
%
%  OUTPUT : 
%           - hFig : Figure handle for further edits

%% General settings

axesFontsize    = 17;
axesFontweight  = 'normal';
labelFontsize   = 20;
labelFontweight = 'normal';
titleFontsize   = 23;
titleFontweight = 'bold';
max_numPCs      = length(res_baseline.Idiff_recon); % Number of principal components
theXlim         = [0 max_numPCs];
theXticks       = 0:10:max_numPCs;
theYlim         = [0 50]; % Only for Idiff
theYticks       = 0:10:max(theYlim);

hFig = figure; % Figure handle

% Idiff curve - Baseline
subplot(3,3,1)
plot(res_baseline.Idiff_recon,'b','LineWidth',3); hold on; % Idiff curve
[Max_val,Idx] = max(res_baseline.Idiff_recon); 
scatter(Idx,Max_val,100,'b','filled','s','MarkerEdgeColor',[0 0 0]); % Mark the optimal point on the curve
xlim(theXlim);
ylim(theYlim);
xticks(theXticks);
yticks(theYticks);
title('Baseline FC','fontweight',titleFontweight,'fontsize',titleFontsize);
xlabel(['Number of components',newline,'   '],'fontweight',labelFontweight,'fontsize',labelFontsize);
ylabel('I_{diff}','fontweight',labelFontweight,'fontsize',labelFontsize);
ax = gca;
ax.FontSize = axesFontsize;
ax.FontName = 'Arial';
ax.FontWeight = axesFontweight;
ax.TickDir = 'out';
ax.LineWidth = 3;
box off;

% Idiff curve - Absolute
subplot(3,3,2)
plot(res_absolute.Idiff_recon,'m','LineWidth',3); hold on; % Idiff curve
[Max_val,Idx] = max(res_absolute.Idiff_recon);
scatter(Idx,Max_val,100,'m','filled','s','MarkerEdgeColor',[0 0 0]); % Mark the optimal point on the curve
xlim(theXlim);
ylim(theYlim);
xticks(theXticks);
yticks(theYticks);
yticks(theYticks);
title('Absolute FC','fontweight',titleFontweight,'fontsize',titleFontsize);
xlabel(['Number of components',newline,'   '],'fontweight',labelFontweight,'fontsize',labelFontsize);
ax = gca;
ax.FontSize = axesFontsize;
ax.FontName = 'Arial';
ax.FontWeight = axesFontweight;
ax.TickDir = 'out';
ax.LineWidth = 3;
box off;

% Idiff curve - Normalized
subplot(3,3,3)
plot(res_normalized.Idiff_recon,'r','LineWidth',3); hold on; % Idiff curve
[Max_val,Idx] = max(res_normalized.Idiff_recon);
scatter(Idx,Max_val,100,'r','filled','s','MarkerEdgeColor',[0 0 0]); % Mark the optimal point on the curve
xlim(theXlim);
ylim(theYlim);
xticks(theXticks);
yticks(theYticks);
yticks(theYticks);
title('Normalized FC','fontweight',titleFontweight,'fontsize',titleFontsize);
xlabel(['Number of components',newline,'   '],'fontweight',labelFontweight,'fontsize',labelFontsize);
ax = gca;
ax.FontSize = axesFontsize;
ax.FontName = 'Arial';
ax.FontWeight = axesFontweight;
ax.TickDir = 'out';
ax.LineWidth = 3;
box off;

% ID_rate curve - Baseline
subplot(3,3,4)
plot(res_baseline.ID_rate_recon,'b','LineWidth',3); hold on; % Idiff curve
[Max_val,Idx] = max(res_baseline.ID_rate_recon); 
scatter(Idx,Max_val,100,'b','filled','s','MarkerEdgeColor',[0 0 0]); % Mark the optimal point on the curve
xlim(theXlim);
ylim([0 1]);
xticks(theXticks);
yticks(0:0.2:1);
xlabel(['Number of components',newline,'   '],'fontweight',labelFontweight,'fontsize',labelFontsize);
ylabel('ID rate','fontweight',labelFontweight,'fontsize',labelFontsize);
ax = gca;
ax.FontSize = axesFontsize;
ax.FontName = 'Arial';
ax.FontWeight = axesFontweight;
ax.TickDir = 'out';
ax.LineWidth = 3;
box off;

% ID_rate curve - Absolute
subplot(3,3,5)
plot(res_absolute.ID_rate_recon,'m','LineWidth',3); hold on; % Idiff curve
[Max_val,Idx] = max(res_absolute.ID_rate_recon);
scatter(Idx,Max_val,100,'m','filled','s','MarkerEdgeColor',[0 0 0]); % Mark the optimal point on the curve
xlim(theXlim);
ylim([0 1]);
xticks(theXticks);
yticks(0:0.2:1);
xlabel(['Number of components',newline,'   '],'fontweight',labelFontweight,'fontsize',labelFontsize);
ax = gca;
ax.FontSize = axesFontsize;
ax.FontName = 'Arial';
ax.FontWeight = axesFontweight;
ax.TickDir = 'out';
ax.LineWidth = 3;
box off;

% ID_rate curve - Normalized
subplot(3,3,6)
plot(res_normalized.ID_rate_recon,'r','LineWidth',3); hold on; % Idiff curve
[Max_val,Idx] = max(res_normalized.ID_rate_recon);
scatter(Idx,Max_val,100,'r','filled','s','MarkerEdgeColor',[0 0 0]); % Mark the optimal point on the curve
xlim(theXlim);
ylim([0 1]);
xticks(theXticks);
yticks(0:0.2:1);
xlabel(['Number of components',newline,'   '],'fontweight',labelFontweight,'fontsize',labelFontsize);
ax = gca;
ax.FontSize = axesFontsize;
ax.FontName = 'Arial';
ax.FontWeight = axesFontweight;
ax.TickDir = 'out';
ax.LineWidth = 3;
box off;

% M_rate curve - Baseline
subplot(3,3,7)
plot(res_baseline.M_rate_recon,'b','LineWidth',3); hold on; % Idiff curve
[Max_val,Idx] = max(res_baseline.M_rate_recon); 
scatter(Idx,Max_val,100,'b','filled','s','MarkerEdgeColor',[0 0 0]); % Mark the optimal point on the curve
xlim(theXlim);
ylim([0 1]);
xticks(theXticks);
yticks(0:0.2:1);
xlabel(['Number of components',newline,'   '],'fontweight',labelFontweight,'fontsize',labelFontsize);
ylabel('Matching rate','fontweight',labelFontweight,'fontsize',labelFontsize);
ax = gca;
ax.FontSize = axesFontsize;
ax.FontName = 'Arial';
ax.FontWeight = axesFontweight;
ax.TickDir = 'out';
ax.LineWidth = 3;
box off;

% M_rate curve - Absolute
subplot(3,3,8)
plot(res_absolute.M_rate_recon,'m','LineWidth',3); hold on; % Idiff curve
[Max_val,Idx] = max(res_absolute.M_rate_recon);
scatter(Idx,Max_val,100,'m','filled','s','MarkerEdgeColor',[0 0 0]); % Mark the optimal point on the curve
xlim(theXlim);
ylim([0 1]);
xticks(theXticks);
yticks(0:0.2:1);
xlabel(['Number of components',newline,'   '],'fontweight',labelFontweight,'fontsize',labelFontsize);
ax = gca;
ax.FontSize = axesFontsize;
ax.FontName = 'Arial';
ax.FontWeight = axesFontweight;
ax.TickDir = 'out';
ax.LineWidth = 3;
box off;

% M_rate curve - Normalized
subplot(3,3,9)
plot(res_normalized.M_rate_recon,'r','LineWidth',3); hold on; % Idiff curve
[Max_val,Idx] = max(res_normalized.M_rate_recon);
scatter(Idx,Max_val,100,'r','filled','s','MarkerEdgeColor',[0 0 0]); % Mark the optimal point on the curve
xlim(theXlim);
ylim([0 1]);
xticks(theXticks);
yticks(0:0.2:1);
xlabel(['Number of components',newline,'   '],'fontweight',labelFontweight,'fontsize',labelFontsize);
ax = gca;
ax.FontSize = axesFontsize;
ax.FontName = 'Arial';
ax.FontWeight = axesFontweight;
ax.TickDir = 'out';
ax.LineWidth = 3;
box off;

set(hFig,'Position',[0 0 1500 1200])

end

